#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
wagtailaltgenerator
----------
Insert image description and tags with the help of computer vision
"""

__title__ = "wagtailaltgenerator"
__version__ = '3.1.0'
__build__ = 310
__author__ = "Martin Sandström"
__license__ = "MIT"
__copyright__ = "Copyright 2016 Martin Sandström"

default_app_config = 'wagtailaltgenerator.apps.AltGeneratorAppConfig'
